Personal Events — Poezio 0.9-dev documentation

# Personal Events

Starting from poezio 0.8, poezio now supports user mood, user activity, user tune, and user gaming.

Those extensions are standardized ways to broadcast informations that might be useful to your contacts (they will receive those informations only if they have indicated their interest in them).

The events are also shown in the roster, next to the contact line:

On the above figure, A stands for Activity, M for Mood, and G for Gaming.

The details are shown with notifications if configured, and in the detailed contact information window, on the bottom left in the roster tab.

You can see below the list of the related options and commands.

Note

All the display_foo_notifications options can be tab-specific, so you can display those notifications only for a specific contact, or the other way around.

## User Mood

Options:

- enable_user_mood
- display_mood_notifications

Commands:

- /mood

## User Activity

Options:

- enable_user_activity
- display_activity_notifications

Commands:

- /activity

## User Gaming

Options:

- enable_user_gaming
- display_gaming_notifications

Commands:

- /gaming

## User Tune

Options:

- enable_user_tune
- display_tune_notifications

Note

There is no /tune command because it wouldn’t be really useful. There was originally a way to broadcast the current tune with the mpd plugin, but it was no good. You should use an external script to do that, or use a player that has the feature.